==> edyuk-1.1.0.tar.bz2: edyuk-1.1.0/translations/designer_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="fr">
<context>
    <name>DesignerPlugin</name>
    <message>
        <location filename="../src/plugins/designer/plugin.cpp" line="92"/>
        <source>Integrated Designer</source>
        <translation>Intégration du Designer</translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/plugin.cpp" line="93"/>
        <source>A simple perspective bringing integration of Qt4 Designer</source>
        <translation>Une perspective offrant l&apos;intégration du Designer de Qt 4</translation>
    </message>
</context>
<context>
    <name>QDesignerActionEditor</name>
    <message>
        <location filename="../src/plugins/designer/qdesigneractioneditor.cpp" line="53"/>
        <source>Actions</source>
        <translation>Actions</translation>
    </message>
</context>
<context>
    <name>QDesignerClient</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerclient.cpp" line="131"/>
        <source>&amp;Preview</source>
        <translation>A&amp;perçu</translation>
    </message>
</context>
<context>
    <name>QDesignerObjectInspector</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerobjectinspector.cpp" line="53"/>
        <source>Object Inspector</source>
        <translation>Inspecteur</translation>
    </message>
</context>
<context>
    <name>QDesignerPerspective</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerperspective.cpp" line="59"/>
        <source>Edit Widgets</source>
        <translation>Editer les widgets</translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/qdesignerperspective.cpp" line="135"/>
        <source>Integrated Qt4 Designer</source>
        <translation>Designer Qt 4 intégré</translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/qdesignerperspective.cpp" line="169"/>
        <source>Qt Designer forms ( *.ui )</source>
        <translation>Interfaces Qt Designer ( *.ui )</translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/qdesignerperspective.cpp" line="294"/>
        <source>untitled form %1</source>
        <translation>interface sans nom %1</translation>
    </message>
</context>
<context>
    <name>QDesignerPropertyEditor</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerpropertyeditor.cpp" line="53"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
</context>
<context>
    <name>QDesignerSignalSlotEditor</name>
    <message>
        <location filename="../src/plugins/designer/qdesignersignalsloteditor.cpp" line="30"/>
        <source>Signal and slots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/qdesignersignalsloteditor.cpp" line="43"/>
        <source>Signals and slots</source>
        <translation>Signaux et slots</translation>
    </message>
</context>
<context>
    <name>QDesignerWidgetBox</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerwidgetbox.cpp" line="53"/>
        <source>Widget Box</source>
        <translation>Boîtes à Widgets</translation>
    </message>
</context>
</TS>

==> edyuk-1.1.1.tar.bz2: edyuk-1.1.1/translations/designer_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>DesignerPlugin</name>
    <message>
        <location filename="../src/plugins/designer/plugin.cpp" line="98"/>
        <source>Integrated Designer</source>
        <translation>Intégration du Designer</translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/plugin.cpp" line="99"/>
        <source>A simple perspective bringing integration of Qt4 Designer</source>
        <translation>Une perspective offrant l&apos;intégration du Designer de Qt 4</translation>
    </message>
</context>
<context>
    <name>QDesignerActionEditor</name>
    <message>
        <location filename="../src/plugins/designer/qdesigneractioneditor.cpp" line="30"/>
        <location filename="../src/plugins/designer/qdesigneractioneditor.cpp" line="53"/>
        <source>Actions</source>
        <translation>Actions</translation>
    </message>
</context>
<context>
    <name>QDesignerClient</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerclient.cpp" line="131"/>
        <source>&amp;Preview</source>
        <translation>A&amp;perçu</translation>
    </message>
</context>
<context>
    <name>QDesignerObjectInspector</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerobjectinspector.cpp" line="30"/>
        <location filename="../src/plugins/designer/qdesignerobjectinspector.cpp" line="53"/>
        <source>Object Inspector</source>
        <translation>Inspecteur</translation>
    </message>
</context>
<context>
    <name>QDesignerPerspective</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerperspective.cpp" line="58"/>
        <source>Edit Widgets</source>
        <translation>Editer les widgets</translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/qdesignerperspective.cpp" line="139"/>
        <source>Integrated Qt4 Designer</source>
        <translation>Designer Qt 4 intégré</translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/qdesignerperspective.cpp" line="172"/>
        <source>Qt Designer forms ( *.ui )</source>
        <translation>Interfaces Qt Designer ( *.ui )</translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/qdesignerperspective.cpp" line="298"/>
        <source>untitled form %1</source>
        <translation>interface sans nom %1</translation>
    </message>
</context>
<context>
    <name>QDesignerPropertyEditor</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerpropertyeditor.cpp" line="31"/>
        <location filename="../src/plugins/designer/qdesignerpropertyeditor.cpp" line="53"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
</context>
<context>
    <name>QDesignerSignalSlotEditor</name>
    <message>
        <location filename="../src/plugins/designer/qdesignersignalsloteditor.cpp" line="30"/>
        <source>Signal and slots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/designer/qdesignersignalsloteditor.cpp" line="43"/>
        <source>Signals and slots</source>
        <translation>Signaux et slots</translation>
    </message>
</context>
<context>
    <name>QDesignerWidgetBox</name>
    <message>
        <location filename="../src/plugins/designer/qdesignerwidgetbox.cpp" line="30"/>
        <location filename="../src/plugins/designer/qdesignerwidgetbox.cpp" line="53"/>
        <source>Widget Box</source>
        <translation>Boîtes à Widgets</translation>
    </message>
</context>
</TS>
